==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dde-update/translations/dde-update_ja.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ja">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation>チェックはほとんど完了しました。もうしばらくお待ちください。</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>準備中</translation>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation>いくつかのエラーを確認しました</translation>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation>デスクトップに移動</translation>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation>ようこそ、システムは正常にアップデートされました</translation>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation>現在のエディション:</translation>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>View Logs</source>
        <translation>ログを見る</translation>
    </message>
    <message>
        <source>Updates successful</source>
        <translation>アップデート完了</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation>まもなくコンピューターが再起動されます %1</translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>まもなくコンピューターの電源がオフになります %1</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation>自動再起動プロセスが失敗しました。手動でデバイスを再起動してください。</translation>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation>自動シャットダウンプロセスが失敗しました。手動でデバイスをシャットダウンしてください。</translation>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Hide Logs</source>
        <translation>ログを隠す</translation>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>アップデートに失敗しました</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>不明なエラー</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>バックアップに失敗しました</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>システムをバックアップできません。アップデートを続行すると、後で古いシステムにロールバックすることができなくなります。</translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>ディスクの空き容量が不足しています。ディスクをクリーンアップしてからやり直してください。</translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation>バックアップサービスに接続できませんでした。もう一度やり直してください。</translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation>アップデートサーバーへの接続に失敗しました。しばらく経ってからやり直してください。</translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation>依存関係エラー</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>DPKGエラー</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>もう一度バックアップする</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>中止</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>アップデートを続行</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>再起動</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>シャットダウン</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation>デスクトップに移動</translation>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>アップデートを準備中...</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation>アップデートのインストール中にシステムを強制的にシャットダウンしたり、電源をオフにしないでください。システムが破損する可能性があります。</translation>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.19.tar.xz: BUILD/src/dde-update/translations/dde-update_ja.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ja">
<context>
    <name>CheckProgressWidget</name>
    <message>
        <source>The check is almost complete, thank you for your patience</source>
        <translation>チェックはほとんど完了しました。もうしばらくお待ちください。</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>準備中</translation>
    </message>
</context>
<context>
    <name>ErrorFrame</name>
    <message>
        <source>Checked for some errors</source>
        <translation>いくつかのエラーを確認しました</translation>
    </message>
</context>
<context>
    <name>SuccessFrame</name>
    <message>
        <source>Go to Desktop</source>
        <translation>デスクトップに移動</translation>
    </message>
    <message>
        <source>Welcome, system updated successfully</source>
        <translation>ようこそ、システムは正常にアップデートされました</translation>
    </message>
    <message>
        <source>Current Edition:</source>
        <translation>現在のエディション:</translation>
    </message>
</context>
<context>
    <name>UpdateCompleteWidget</name>
    <message>
        <source>Updates successful</source>
        <translation>アップデート完了</translation>
    </message>
    <message>
        <source>Your computer will reboot soon %1</source>
        <translation>まもなくコンピューターが再起動されます %1</translation>
    </message>
    <message>
        <source>Your computer will be turned off soon %1</source>
        <translation>まもなくコンピューターの電源がオフになります %1</translation>
    </message>
    <message>
        <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
        <translation>自動再起動プロセスが失敗しました。手動でデバイスを再起動してください。</translation>
    </message>
    <message>
        <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
        <translation>自動シャットダウンプロセスが失敗しました。手動でデバイスをシャットダウンしてください。</translation>
    </message>
    <message>
        <source>View update logs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateLogWidget</name>
    <message>
        <source>Export</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The log has been exported to the desktop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Log export failed, please try again</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Update failed</source>
        <translation>アップデートに失敗しました</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>不明なエラー</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>バックアップに失敗しました</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>システムをバックアップできません。アップデートを続行すると、後で古いシステムにロールバックすることができなくなります。</translation>
    </message>
    <message>
        <source>Insufficient disk space. Please clean up your disk and try again.</source>
        <translation>ディスクの空き容量が不足しています。ディスクをクリーンアップしてからやり直してください。</translation>
    </message>
    <message>
        <source>Failed to connect to backup services. Please check and retry again.</source>
        <translation>バックアップサービスに接続できませんでした。もう一度やり直してください。</translation>
    </message>
    <message>
        <source>Failed to connect to update services. Please check and retry again.</source>
        <translation>アップデートサーバーへの接続に失敗しました。しばらく経ってからやり直してください。</translation>
    </message>
    <message>
        <source>Dependency error</source>
        <translation>依存関係エラー</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>DPKGエラー</translation>
    </message>
    <message>
        <source>Back Up Again</source>
        <translation>もう一度バックアップする</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>中止</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>アップデートを続行</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>再起動</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>シャットダウン</translation>
    </message>
    <message>
        <source>Go to Desktop</source>
        <translation>デスクトップに移動</translation>
    </message>
</context>
<context>
    <name>UpdatePrepareWidget</name>
    <message>
        <source>Preparing for updates…</source>
        <translation>アップデートを準備中...</translation>
    </message>
</context>
<context>
    <name>UpdateProgressWidget</name>
    <message>
        <source>Do not force a shutdown or power off when installing updates. Otherwise, your system may be damaged.</source>
        <translation>アップデートのインストール中にシステムを強制的にシャットダウンしたり、電源をオフにしないでください。システムが破損する可能性があります。</translation>
    </message>
    <message>
        <source>View update logs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Collapse update logs</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>updatelog</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
